

library(MCMCpack)
library(ggplot2)
library(gridExtra)
library(dplyr)
library(gtools)

cdi = read.csv("C:/Users/eritchie/Documents/gen_CDI_weights/input/cdiresults_hardcoded.csv",header=TRUE)
cdi.mat = data.matrix(cdi[,3:9])
cdi_real = cdi[,10]

rept = 10^6

alpha = 30
param = c(rep(alpha,7))
x = rdirichlet(rept,param)

scores = cdi.mat%*%t(x)

getrank = function(x){
	return(41 - rank(x))
	}
collectranks = apply(scores,2,getrank)


func = function(v,x){
	return(sum(v == x))
}
testm= NULL
for(i in 1:40){
	testm = cbind(testm,apply(collectranks,1,func,i))
}

testdf = as.data.frame(testm)
testdf$country = cdi[,1]
testdf = testdf[order(cdi_real),]
testdf$id = 40:1

testlong = reshape(testdf,direction="long",idvar=c('country','id'),varying=list(1:40))

rankgraph = ggplot(testlong,aes(y = reorder(country,id),x=time)) + geom_raster(aes(fill=V1)) +
	scale_fill_gradient(low='light gray', high="black",na.value=NA,limits=c(0.1,rept)) + 
	theme(panel.background=element_rect(fill='white'))
rankgraph = rankgraph + theme(legend.position = "none") + 
		xlab("Rank") + ylab("Country") 

#rgb(red=20,green=200,blue=170,maxColorValue=255)

#################################################################################################
### Explore distribution

xdf = as.data.frame(x)

for (i in 1:7) {
	assign(paste('p',i,sep=""), ggplot(xdf,aes(x=xdf[,i])) + geom_density() + 
		stat_function(fun = dnorm, args=list(mean = mean(x[,i]),sd=sd(x[,i])),color="blue") + labs(x=paste("Component",i,sep=" ")))
}

title = paste("Dirichlet, alpha=",alpha," (blue line = normal density)",sep="")
file = paste("C:/Users/eritchie/Documents/alpha",alpha,".jpg",sep="")

densities = grid.arrange(p1,p2,p3,p4,p5,p6,p7,ncol=2)
g = arrangeGrob(p1,p2,p3,p4,p5,p6,p7,ncol=2,top=title)
ggsave(file,g)

file2 = paste("C:/Users/eritchie/Documents/rankgraph_alpha30.jpg",sep="")
ggsave(file2,rankgraph)

###############################################################################

####		METHOD 2 - ALL PERMUTATIONS

###############################################################################

bottom.1 = 0.05
top.1 = 0.25
incr.1 = (top.1 - bottom.1)/12

allw.1 = permutations(13,7,v=seq(bottom.1,top.1,by=incr.1),repeats.allowed=T)
sums.1 = rowSums(allw.1)
allw.1 = allw.1[sums.1==1,]

scores.p1 = allw.1%*%t(cdi.mat)
collectranks.p1 = apply(scores.p1,1,getrank)

testm.p1 = NULL
for(i in 1:40){
	testm.p1 = cbind(testm.p1,apply(collectranks.p1,1,func,i))
}

testdf.p1 = as.data.frame(testm.p1)
testdf.p1$country = cdi[,1]
testdf.p1 = testdf.p1[order(cdi_real),]
testdf.p1$id = 40:1

testlong.p1 = reshape(testdf.p1,direction="long",idvar=c('country','id'),varying=list(1:40))


rankgraph.p1 = ggplot(testlong.p1,aes(y = reorder(country,id),x=time)) + geom_raster(aes(fill=V1)) +
	scale_fill_gradient(low='light gray', high="black",na.value=NA,limits=c(0.1,dim(allw.1)[1])) + 
	theme(panel.background=element_rect(fill='white'))
rankgraph.p1 = rankgraph.p1 + theme(legend.position = "none") + 
		xlab("Rank") + ylab("Country") 


bottom.2 = 0.0
top.2 = 0.3
incr.2 = (top.2 - bottom.2)/12

allw.2 = permutations(13,7,v=seq(bottom.2,top.2,by=incr.2),repeats.allowed=T)
sums.2 = rowSums(allw.2)
allw.2 = allw.2[sums.2==1,]
dim(allw.2)
hist(allw.2[,1])
unique(allw.2[,1])

scores.p2 = allw.2%*%t(cdi.mat)
collectranks.p2 = apply(scores.p2,1,getrank)

testm.p2 = NULL
for(i in 1:40){
	testm.p2 = cbind(testm.p2,apply(collectranks.p2,1,func,i))
}

testdf.p2 = as.data.frame(testm.p2)
testdf.p2$country = cdi[,1]
testdf.p2 = testdf.p2[order(cdi_real),]
testdf.p2$id = 40:1

testlong.p2 = reshape(testdf.p2,direction="long",idvar=c('country','id'),varying=list(1:40))


rankgraph.p2 = ggplot(testlong.p2,aes(y = reorder(country,id),x=time)) + geom_raster(aes(fill=V1)) +
	scale_fill_gradient(low='light gray', high="black",na.value=NA,limits=c(0.1,dim(allw.2)[1])) + 
	theme(panel.background=element_rect(fill='white'))
rankgraph.p2  = rankgraph.p2 + theme(legend.position = "none") + 
		xlab("Rank") + ylab("Country") 

grid.arrange(rankgraph.p1,rankgraph.p2,ncol=2)